import React, { Component, PropTypes } from 'react'
import { withTheme } from 'styled-components'
import Box from './Box'
import Text from './Text'

class AvatarImage extends Component {
  constructor() {
    super()
    this.handleError = this.handleError.bind(this)
    this.state = {
      failed: false
    }
  }

  handleError() {
    this.setState({ failed: true })
  }

  render() {
    if (this.state.failed || !this.props.src) return null
    return (
      <Box
        is='img'
        src={this.props.src}
        onError={this.handleError}
        height='100%'
        width='100%'
        {...this.props} />
    )
  }
}

const AvatarName = ({ children }) => {
  return <Text textStyle='body1' truncate>{children}</Text>
}

const AvatarCircle = (props) => <Box display='inline-block' circle overflow='hidden' {...props} />

const AvatarInitials = (props) => <Text white {...props} />

function getInitials (name) {
  if (!name || typeof name !== 'string') return '?';
  return name
    .replace(/\s+/, ' ')
    .split(' ')
    .slice(0, 2)
    .map(v => v[0])
    .join('')
}

const AvatarImageSize = {
  small: '30px',
  default: '40px'
}

const Avatar = ({ src, imageSize, children, nameShown, theme, width, nameWidth, ...props }) => {
  const size = AvatarImageSize.hasOwnProperty(imageSize) ? AvatarImageSize[imageSize] : imageSize
  return (
    <Box title={children} textAlign='center' {...props}>
      <AvatarCircle backgroundColor={theme.colors.primary} width={size} height={size}>
        <AvatarImage src={src} />
        <AvatarInitials lineHeight={size}>{getInitials(children)}</AvatarInitials>
      </AvatarCircle>
      {nameShown ? <AvatarName width={nameWidth}>{children}</AvatarName> : null}
    </Box>
  )
}

Avatar.propTypes = {
  ...Box.propTypes,
  showName: PropTypes.bool,
  children: PropTypes.string,
  nameWidth: PropTypes.string,
  imageSize: PropTypes.oneOfType([
    PropTypes.string,
    PropTypes.oneOf(['small', 'default'])
  ])
}

Avatar.defaultProps = {
  nameWidth: '100px',
  display: 'inline-block',
  imageSize: 'default',
  nameShown: false
}

export default withTheme(Avatar)
