import React, { PropTypes } from 'react'
import cx from 'classnames'
import theme from './theme'

const SpaceScale = theme.space

const SpaceScalePropType = PropTypes.oneOf(
  SpaceScale.map((_, i) => i)
)

const NegativeIncludedSpaceScalePropType = PropTypes.oneOf(
  [...SpaceScale.map((_, i) => -i), ...SpaceScale.map((_, i) => i)]
)

const SpaceType = {
  VERTICAL: 'vertical',
  HORIZONTAL: 'horizontal'
}

const SpaceTypePropType = PropTypes.oneOf(Object.values(SpaceType))

const parseSpaceProps = ({
  step,
  type = SpaceType.VERTICAL, /* backwards compatible */
  value = 0,
  x,
  y,
  className,
  ...props
}) => {
  const style = {}
  let val;

  if (x !== undefined) {
    val = SpaceScale[x]
  } else if (y !== undefined) {
    val = SpaceScale[y]
  } else {
    val = `${value}px`
  }

  if (x || type === SpaceType.HORIZONTAL) {
    style.display = 'inline-block'
    style.width = val
  } else if (y || type === SpaceType.VERTICAL) {
    style.display = 'block'
    style.height = val
  }

  return { className: cx('Space', className), style, ...props }
}

const Space = ({
  is = 'div',
  ...props
}) => React.createElement(is, parseSpaceProps(props))

Space.propTypes = {
  type: SpaceTypePropType,
  is: PropTypes.string,
  x: SpaceScalePropType,
  y: SpaceScalePropType,
  value: PropTypes.number /* px value */
}

Space.displayName = 'Space'

export {
  Space,
  SpaceScale,
  SpaceScalePropType,
  NegativeIncludedSpaceScalePropType,
  SpaceType,
  SpaceTypePropType
}
