import React, { PropTypes } from 'react'
import styled, { css } from 'styled-components'
import theme from './../components/theme'

const getTextStyle = ({ fontSize, fontWeight, lineHeight, letterSpacing }, textStyle) => `
  font-size: ${fontSize};
  font-weight: ${fontWeight};
  line-height: ${lineHeight};
  letter-spacing: ${letterSpacing};
  ${textStyle.indexOf('caps') > -1 ? `text-transform: uppercase;` : ''}
`

const styles = ({
  textStyle,
  bold,
  theme
}) => css`
  ${textStyle !== undefined ? getTextStyle(theme.textStyles[textStyle], textStyle) : ''}
  ${bold && `font-weight: 500;`}
`

const withTextStyles = (Comp) => {
  const HoComp = styled(({
    textStyle,
    bold,
    ...props
  }) => React.createElement(Comp, props))`${styles}`

  HoComp.propTypes = {
    ...Comp.propTypes,
    textStyle: PropTypes.oneOf(Object.keys(theme.textStyles)),
    bold: PropTypes.bool
  }

  HoComp.displayName = Comp.displayName

  return HoComp
}

export {
  withTextStyles
}
