import React from 'react';
import { storiesOf, action, linkTo } from '@kadira/storybook'
import {
  App,
  Box,
  Pane,
  Content
} from '../components'

export default function boxStory (module) {
  storiesOf('Box', module)
    .add('usage', () => (
      <App>
        <Pane white padding={10}>
          <Content markdown>
{`
# Box

The Box component is the base component for most other components.
All the higher order components in \`enhancers\` are applied to Box.

prop | type | default | description
-----|------|---------|-------------
\`rounded\` | boolean/1..3 | 1 | border-radius: x; boolean
\`shadow\` | boolean/1..2 | 1 | box-shadow: x;
\`clearfix\` | boolean | | applies a clearfix
\`backgroundColor\` | string | | background-color: x;
\`circle\` | boolean | | border-radius: 9999px;
\`overflow\` | hidden, visible, scroll, auto, inherit, initial | | overflow: x;

**All API's below apply to Box**

## Display API

Available on \`<Box />\` or \`withDisplay(Comp)\`.
Uses inline styles.

\`\`\`
<Box display='block' />
<Box display='inline-block' />
<Box display='flex' />
\`\`\`

prop | value | description
-----|-------|-------------
\`display\`| block, inline-block, inline, table, table-row, table-cell, flex, inline-flex | display: x;

## Dimensions API

Available on \`<Box />\` or \`withDimensions(Comp)\`.
Uses inline styles.

\`\`\`
<Box width='200px' />
<Box width={6} />
<Box height='40px' />
<Box height='40px' width='40px' />
<Box minWidth='100px' />
\`\`\`

prop | type | description
-----|------| -------
\`height\`| string | height: x;
\`width\`| string/[1..12] | given a number 1..12 as x, return {100/x}%
\`minWidth\`| string | min-width: x;
\`minHeight\`| string | min-height: x;
\`maxWidth\`| string | max-width: x;
\`maxHeight\`| string | max-height: x;

## Text Styles API

Available on \`<Box />\` or \`withTextStyles(Comp)\`.

\`\`\`
<Box textStyle='display1'>Display (1)</Box>
<Box textStyle='display2'>Display 2</Box>
<Box textStyle='display3'>Display 3</Box>
<Box textStyle='display4'>Display 4</Box>
<Box textStyle='body1'>Body (1)</Box>
<Box textStyle='body2'>Body 2</Box>
<Box textStyle='mono'>Mono</Box>
<Box textStyle='caps1'>Caps 1</Box>
<Box textStyle='caps2'>Caps 2</Box>
\`\`\`

`}
          </Content>
          <Box textStyle='display1'>Display (1)</Box>
          <Box textStyle='display2'>Display 2</Box>
          <Box textStyle='display3'>Display 3</Box>
          <Box textStyle='display4'>Display 4</Box>
          <Box textStyle='body1'>Body (1)</Box>
          <Box textStyle='body2'>Body 2</Box>
          <Box textStyle='mono'>Mono</Box>
          <Box textStyle='caps1'>Caps 1</Box>
          <Box textStyle='caps2'>Caps 2</Box>
          <Content markdown>
{`

prop | type | description
-----|------|------------
\`textStyle\` | display1, display2, display3, display4, body1, body2, mono, caps1, caps2 | use text style

## Spacing API

Available on \`<Box />\` or \`withSpacing(Comp)\`.
Uses inline styles. Uses the spacing scale.

\`\`\`
<Box padding />
<Box margin />
<Box paddingTop={3} paddingBottom={3} />

<!-- DANGER: Avoid this as much as possible -->
<Box marginTop='-2px' />
\`\`\`

prop | type | description
-----|------| -------
\`padding\` | number/boolean/string | uses 4 on spacing scale by default
\`paddingTop\` | number/boolean/string | uses 4 on spacing scale by default
\`paddingRight\` | number/boolean/string | uses 4 on spacing scale by default
\`paddingBottom\` | number/boolean/string | uses 4 on spacing scale by default
\`paddingLeft\` | number/boolean/string | uses 4 on spacing scale by default
\`margin\` | number/boolean/string | uses 4 on spacing scale by default
\`marginTop\` | number/boolean/string | uses 4 on spacing scale by default
\`marginRight\` | number/boolean/string | uses 4 on spacing scale by default
\`marginBottom\` | number/boolean/string | uses 4 on spacing scale by default
\`marginLeft\` | number/boolean/string | uses 4 on spacing scale by default

### Spacing Scale

**step 4 is default**

scale step number | value
------------------|-------
0 | 0
1 | 4px
2 | 8px
3 | 12px
4 | 16px
5 | 24px
6 | 32px
7 | 40px
8 | 48px
9 | 64px
10 | 80px

# Flex API

Available on \`<Box />\` or \`withFlex(Comp)\`. Uses styled-components.

Need a flexbox refresher? [Complete guide to flexbox](https://css-tricks.com/snippets/css/a-guide-to-flexbox/)

\`\`\`
<Box display='flex'>
  <Pane dark padding width={3}>Left</Pane>
  <Pane tint={2} padding flexAuto>Main</Pane>
  <Pane dark padding width={3}>Right</Pane>
</Box>
\`\`\`
`}
          </Content>
          <Box display='flex'>
            <Pane dark padding width={3} flex='0 0 auto'>Left</Pane>
            <Pane tint={2} flexAuto padding>Main</Pane>
            <Pane dark padding width={3} flex='0 0 auto'>Right</Pane>
          </Box>
          <Content markdown>
{`
prop | type | description
-----|------|------------
\`flex\`    | string | flex: x;
\`flexWrap\`    | boolean | flex-wrap: wrap
\`flexAlign\`   | string  | align-items
\`justifyContent\` | center, space-around, space-between, flex-start, flex-end  | justify-content
\`flexColumn\`| boolean | flex-direction: column
\`flexAuto\`| boolean | flex: 1 1 auto
\`flexNone\`| boolean | flex: none
\`flexOrder\`   | number  | order

## Borders API

Available on \`<Box />\` or \`withBorders(Comp)\`. Uses inline styles.

Some components implement a border color already, such as Pane.

prop | type | description
-----|------|------------
\`borderColor\` | string | border-color: x;
\`borderLeft\` | boolean | border-left: 1px solid;
\`borderRight\` | boolean | border-right: 1px solid;
\`borderTop\` | boolean | border-top: 1px solid;
\`borderBottom\` | boolean | border-bottom: 1px solid;

## Position API

Available on \`<Box />\` or \`withPosition(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`position\` | relative, absolute, fixed, static | position: x;
\`top\` | string | top: x;
\`right\` | string | right: x;
\`bottom\` | string | bottom: x;
\`left\` | string | left: x;

## Overflow API

Available on \`<Box />\` or \`withOverflow(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`overflow\` | hidden, visible, scroll, auto, inherit, initial | overflow: x;

## Text Align API

Available on \`<Box />\` or \`withTextAlign(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`textAlign\` | left, center, right | text-align: x;

## Truncate API

Available on \`<Box />\` or \`withTruncate(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`truncate\` | boolean | sets overflow ellipsis and props to make it work

## Rotate API

Available on \`<Box />\` or \`withRotate(Comp)\`. Uses inline styles.

prop | type | description
-----|------|------------
\`rotate\` | string | sets tranforms rotate

`}
          </Content>
        </Pane>
      </App>
    ))
}
